import re
from django import http
from django.conf import settings

class SigmundAllowOriginMiddleware(object):
    def process_request(self, request):
        if 'HTTP_ACCESS_CONTROL_REQUEST_METHOD' in request.META:
            response = http.HttpResponse()
            origin = request.META.get('HTTP_ORIGIN')
            origin_regex = getattr(settings, 'SIGMUND_ALLOW_ORIGIN', None)
            if origin_regex and re.match(origin_regex, origin):
                response['Access-Control-Allow-Headers'] = 'Accept,Origin,Content-Type'
                response['Access-Control-Allow-Methods'] = 'POST,GET,OPTIONS,PUT'
                response['Access-Control-Allow-Origin'] = origin
            else:
                response['Access-Control-Allow-Origin'] = 'null'
            return response
        return None

    def process_response(self, request, response):
        if response.has_header('Access-Control-Allow-Origin'):
            return response
        origin = request.META.get('HTTP_ORIGIN')
        response['Access-Control-Allow-Headers'] = 'Accept,Origin,Content-Type'
        response['Access-Control-Allow-Methods'] = 'POST,GET,OPTIONS,PUT'
        response['Access-Control-Allow-Origin'] = origin
        return response



from django.conf import settings
from logging import Handler
import requests, urlparse

class SigmundHandler(Handler):

    def __init__(self):
        super(SigmundHandler, self).__init__()

    def emit(self, record):
        if not hasattr(settings, 'SIGMUND_URL') or not hasattr(
                       settings, 'SIGMUND_USERNAME') or not hasattr(
                       settings, 'SIGMUND_API_KEY'):
            return

        url = urlparse.urljoin(settings.SIGMUND_URL, '/api/v1/sigmund/')

        headers = {
            'Authorization': 'ApiKey {username}:{api_key}'.format(
                username=settings.SIGMUND_USERNAME,
                api_key=settings.SIGMUND_API_KEY),
        }

        params = {
            'message': self.format(record),
            'level': record.levelname,
            'filename': record.filename,
            'line': record.lineno,
            'user_agent': '',
            'ip_address': '',
            'timestamp': record.created,
        }

        requests.post(url, params, headers=headers)

if __name__ == '__main__':
    print SigmundHandler()



from models import LogEntry
from tastypie.authentication import ApiKeyAuthentication
from tastypie.authorization import Authorization
from tastypie.resources import ModelResource
from tastypie.serializers import Serializer

class SigmundResource(ModelResource):
    class Meta:
        queryset = LogEntry.objects.all()
        authentication = ApiKeyAuthentication()
        authorization = Authorization()
        serializer = Serializer(formats=['json', 'jsonp'])

    def hydrate(self, bundle):
        bundle.data['ip_address'] = bundle.request.META.get('REMOTE_ADDR')
        bundle.data['user_agent'] = bundle.request.META.get('HTTP_USER_AGENT')
        return bundle



from django.db import models

class LogEntry(models.Model):
    # Log Levels
    FATAL = 'FATAL'
    ERROR = 'ERROR'
    WARNING = 'WARNING'
    INFO = 'INFO'
    DEBUG = 'DEBUG'
    TRACE = 'TRACE'
    LOG_LEVELS = (
        (TRACE, TRACE),
        (DEBUG, DEBUG),
        (INFO, INFO),
        (WARNING, WARNING),
        (ERROR, ERROR),
        (FATAL, FATAL),
    )

    # Model Fields
    message = models.TextField(default='')
    level = models.CharField(max_length=7, choices=LOG_LEVELS, default=TRACE)
    filename = models.CharField(max_length=1024, default='')
    line = models.IntegerField(null=True)
    user_agent = models.CharField(max_length=1024, default='')
    ip_address = models.IPAddressField(default='')
    timestamp = models.DateTimeField(auto_now_add=True)



#!/usr/bin/env python

from distutils.core import setup

setup(name='sigmund-remote-logger',
      version='0.9.1',
      description='Sigmund is a remote logging service for Django.',
      author='Matt Caldwell',
      author_email='matt.caldwell@gmail.com',
      url='https://github.com/mattcaldwell/sigmund-remote-logger',
      packages=['sigmund', 'sigmund.logging',]
)
